4.28. umbra.globals.uiConstants — Umbra 1.0.9 documentation

# 4.28. umbra.globals.uiConstants

uiConstants.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines Umbra package ui constants through the `UiConstants` class.

Others:

## 4.28.1. Classes

class `umbra.globals.uiConstants.` `UiConstants`

  Defines Umbra package ui constants.

  `uiFile` = u'Umbra.ui'

    Parameters: | uiFile (unicode) – Application ui file.

  `processingUiFile` = u'Processing.ui'

    Parameters: | processingUiFile (unicode) – Processing ui file.

  `reporterUiFile` = u'Reporter.ui'

    Parameters: | reporterUiFile (unicode) – Reporter ui file.

  `windowsStylesheetFile` = u'styles/Windows_styleSheet.qss'

    Parameters: | windowsStylesheetFile (unicode) – Application Windows Os stylesheet file.

  `darwinStylesheetFile` = u'styles/Darwin_styleSheet.qss'

    Parameters: | darwinStylesheetFile (unicode) – Application Mac Os X Os stylesheet file.

  `linuxStylesheetFile` = u'styles/Linux_styleSheet.qss'

    Parameters: | linuxStylesheetFile (unicode) – Application Linux Os stylesheet file.

  `windowsFullScreenStylesheetFile` = u'styles/Windows_FullScreen_styleSheet.qss'

    Parameters: | windowsFullScreenStylesheetFile (unicode) – Application Windows Os fullscreen stylesheet file.

  `darwinFullScreenStylesheetFile` = u'styles/Darwin_FullScreen_styleSheet.qss'

    Parameters: | darwinFullScreenStylesheetFile (unicode) – Application Mac Os X Os fullscreen stylesheet file.

  `linuxFullScreenStylesheetFile` = u'styles/Linux_FullScreen_styleSheet.qss'

    Parameters: | linuxFullScreenStylesheetFile (unicode) – Application Linux Os fullscreen stylesheet file.

  `windowsStyle` = u'plastique'

    Parameters: | windowsStyle (unicode) – Application Windows Os style.

  `darwinStyle` = u'plastique'

    Parameters: | darwinStyle (unicode) – Application Mac Os X Os style.

  `linuxStyle` = u'plastique'

    Parameters: | linuxStyle (unicode) – Application Linux Os style.

  `settingsFile` = u'preferences/Default_Settings.rc'

    Parameters: | settingsFile (unicode) – Application defaults settings file.

  `layoutsFile` = u'layouts/Default_Layouts.rc'

    Parameters: | layoutsFile (unicode) – Application defaults layouts file.

  `applicationWindowsIcon` = u'images/Icon_Dark.png'

    Parameters: | applicationWindowsIcon (unicode) – Application icon file.

  `splashScreenImage` = u'images/Umbra_SpashScreen.png'

    Parameters: | splashScreenImage (unicode) – Application splashscreen image.

  `logoImage` = u'images/Umbra_Logo.png'

    Parameters: | logoImage (unicode) – Application logo image.

  `defaultToolbarIconSize` = 32

    Parameters: | defaultToolbarIconSize (int) – Application toolbar icons size.

  `customLayoutsIcon` = u'images/Custom_Layouts.png'

    Parameters: | customLayoutsIcon (unicode) – Application Custom Layouts icon.

  `customLayoutsHoverIcon` = u'images/Custom_Layouts_Hover.png'

    Parameters: | customLayoutsHoverIcon (unicode) – Application Custom Layouts hover icon.

  `customLayoutsActiveIcon` = u'images/Custom_Layouts_Active.png'

    Parameters: | customLayoutsActiveIcon (unicode) – Application Custom Layouts active icon.

  `miscellaneousIcon` = u'images/Miscellaneous.png'

    Parameters: | miscellaneousIcon (unicode) – Application Miscellaneous icon.

  `miscellaneousHoverIcon` = u'images/Miscellaneous_Hover.png'

    Parameters: | miscellaneousHoverIcon (unicode) – Application Miscellaneous hover icon.

  `miscellaneousActiveIcon` = u'images/Miscellaneous_Active.png'

    Parameters: | miscellaneousActiveIcon (unicode) – Application Miscellaneous active icon.

  `developmentIcon` = u'images/Development.png'

    Parameters: | developmentIcon (unicode) – Application Development icon.

  `developmentHoverIcon` = u'images/Development_Hover.png'

    Parameters: | developmentHoverIcon (unicode) – Application Development hover icon.

  `developmentActiveIcon` = u'images/Development_Active.png'

    Parameters: | developmentActiveIcon (unicode) – Application Development active icon.

  `preferencesIcon` = u'images/Preferences.png'

    Parameters: | preferencesIcon (unicode) – Application Preferences icon.

  `preferencesHoverIcon` = u'images/Preferences_Hover.png'

    Parameters: | preferencesHoverIcon (unicode) – Application Preferences hover icon.

  `preferencesActiveIcon` = u'images/Preferences_Active.png'

    Parameters: | preferencesActiveIcon (unicode) – Application Preferences active icon.

  `startupLayout` = u'startupCentric'

    Parameters: | startupLayout (unicode) – Application startup layout.

  `helpFile` = u'http://thomasmansencal.com/Sharing/Umbra/Support/Documentation/Help/Umbra_Manual.html'

    Parameters: | helpFile (unicode) – Application online help file.

  `apiFile` = u'http://thomasmansencal.com/Sharing/Umbra/Support/Documentation/Api/index.html'

    Parameters: | apiFile (unicode) – Application online Api file.

  `developmentLayout` = u'developmentCentric'

    Parameters: | developmentLayout (unicode) – Application development layout.

  `pythonGrammarFile` = u'grammars/Python/Python.grc'

    Parameters: | pythonGrammarFile (unicode) – Python language grammar file.

  `loggingGrammarFile` = u'grammars/Logging/Logging.grc'

    Parameters: | loggingGrammarFile (unicode) – Logging language grammar file.

  `textGrammarFile` = u'grammars/Text/Text.grc'

    Parameters: | textGrammarFile (unicode) – Text language grammar file.

  `invalidLinkHtmlFile` = u'htmls/Invalid_Link.html'

    Parameters: | invalidLinkHtmlFile (unicode) – Invalid link html file.

  `crittercismId` = u'51290b63421c983d17000490'

    Parameters: | crittercismId (unicode) – Crittercism Id.